@@ -28,7 +28,6 @@
 #' ```
 #'
 #' @inheritParams ClusterFuture-class
-#' @inheritParams multiprocess
 #' @inheritParams Future-class
 #' @inheritParams future
 #'
@@ -47,4 +46,7 @@ cluster <- function(..., persistent = FALSE, workers = availableWorkers(), envir
 }
 class(cluster) <- c("cluster", "multiprocess", "future", "function")
 attr(cluster, "init") <- TRUE
+attr(cluster, "cleanup") <- function() {
+  ClusterRegistry(action = "stop")
+}
 attr(cluster, "tweakable") <- quote(c(makeClusterPSOCK_args(), "persistent"))
