@@ -7,6 +7,21 @@
 #'  change in future versions of the package.  Please use with care until
 #'  further notice._
 #'
+#' @section Packages must not change future options:
+#'
+#' Just like for other R options, as a package developer you must _not_ change
+#' any of the below `future.*` options.  Only the end-user should set these.
+#' If you find yourself having to tweak one of the options, make sure to
+#' undo your changes immediately afterward.  For example, if you want to
+#' bump up the `future.globals.maxSize` limit when creating a future,
+#' use something like the following inside your function:
+#'
+#' ```r
+#' oopts <- options(future.globals.maxSize = 1.0 * 1e9)  ## 1.0 GB
+#' on.exit(options(oopts))
+#' f <- future({ expr })  ## Launch a future with large objects
+#' ```
+#'
 #' @section Settings moved to the 'parallelly' package:
 #' Several functions have been moved to the \pkg{parallelly} package:
 #'
@@ -33,7 +48,7 @@
 #'
 #'  \item{\option{future.globals.maxSize}:}{(numeric) Maximum allowed total size (in bytes) of global variables identified. Used to prevent too large exports. If set of `+Inf`, then the check for large globals is skipped. (Default: `500 * 1024 ^ 2` = 500 MiB)}
 #'
-#'   \item{\option{future.globals.onReference}: (_beta feature - may change_)}{(character string) Controls whether the identified globals should be scanned for so called _references_ (e.g. external pointers and connections) or not.  It is unlikely that another \R process ("worker") can use a global that uses a internal reference of the master \R process - we call such objects _non-exportable globals_.
+#'   \item{\option{future.globals.onReference}: (_beta feature - may change_)}{(character string) Controls whether the identified globals should be scanned for so called _references_ (e.g. external pointers and connections) or not.  It is unlikely that another \R process ("worker") can use a global that uses a internal reference of the master \R process---we call such objects _non-exportable globals_.
 #'    If this option is `"error"`, an informative error message is produced if a non-exportable global is detected.
 #'    If `"warning"`, a warning is produced, but the processing will continue; it is likely that the future will be resolved with a run-time error unless processed in the master \R process (e.g. `plan(sequential)` and `plan(multicore)`).
 #'    If `"ignore"`, no scan is performed.
@@ -46,9 +61,16 @@
 #'
 #'  \item{\option{future.rng.onMisuse}: (_beta feature - may change_)}{(character string) If random numbers are used in futures, then parallel (L'Ecuyer-CMRG) RNG should be used in order to get statistical sound RNGs. The defaults in the future framework assume that _no_ random number generation (RNG) is taken place in the future expression because L'Ecuyer-CMRG RNGs come with an unnecessary overhead if not needed.  To protect against mistakes, the future framework attempts to detect when random numbers are used despite L'Ecuyer-CMRG RNGs are not in place.  If this is detected, and `future.rng.onMisuse = "error"`, then an informative error message is produced.  If `"warning"`, then a warning message is produced.  If `"ignore"`, no check is performed. (Default: `"warning"`)}
 #'
+#'  \item{\option{future.globalenv.onMisuse}: (_beta feature - may change_)}{(character string) Assigning variables to the global environment for the purpose of using the variable at a later time makes no sense with futures, because the next future may be evaluated in different R process.  To protect against mistakes, the future framework attempts to detect when variables are added to the global environment.  If this is detected, and `future.globalenv.onMisuse = "error"`, then an informative error message is produced.  If `"warning"`, then a warning message is produced.  If `"ignore"`, no check is performed. (Default: `"ignore"`)}
+#'
+#'  \item{\option{future.onFutureCondition.keepFuture}:}{(logical) If `TRUE`, a `FutureCondition` keeps a copy of the `Future` object that triggered the condition. If `FALSE`, it is dropped. (Default: `TRUE`)}
+#'
 #'  \item{\option{future.wait.timeout}:}{(numeric) Maximum waiting time (in seconds) for a free worker before a timeout error is generated. (Default: `30 * 24 * 60 * 60` (= 30 days))}
 #'
-#'  \item{\option{future.wait.interval}:}{(numeric) Initial interval (in seconds) between polls. (Default: `0.2` = 0.2 seconds)}
+#'  \item{\option{future.wait.interval}:}{(numeric) Initial interval (in
+#'  seconds) between polls. This controls the polling frequency for finding
+#'  an available worker when all workers are currently busy. It also controls
+#'  the polling frequency of `resolve()`. (Default: `0.01` = 0.01 seconds)}
 #'
 #'  \item{\option{future.wait.alpha}:}{(numeric) Positive scale factor used to increase the interval after each poll. (Default: `1.01`)}
 #' }
@@ -60,7 +82,7 @@
 #'
 #' @section Options for controlling package startup:
 #' \describe{
-#'  \item{\option{future.startup.script}:}{(character vector or a logical) Specifies zero of more future startup scripts to be sourced when the \pkg{future} package is _attached_. It is only the first existing script that is sourced. If none of the specified files exist, nothing is sourced - there will be neither a warning nor an error.
+#'  \item{\option{future.startup.script}:}{(character vector or a logical) Specifies zero of more future startup scripts to be sourced when the \pkg{future} package is _attached_. It is only the first existing script that is sourced. If none of the specified files exist, nothing is sourced---there will be neither a warning nor an error.
 #'  If this option is not specified, environment variable \env{R_FUTURE_STARTUP_SCRIPT} is considered, where multiple scripts may be separated by either a colon (`:`) or a semicolon (`;`). If neither is set, or either is set to `TRUE`, the default is to look for a \file{.future.R} script in the current directory and then in the user's home directory.  To disable future startup scripts, set the option or the environment variable to `FALSE`.  _Importantly_, this option is _always_ set to `FALSE` if the \pkg{future} package is loaded as part of a future expression being evaluated, e.g. in a background process. In order words, they are sourced in the main \R process but not in future processes. (Default: `TRUE` in main \R process and `FALSE` in future processes / during future evaluation)}
 #'
 #'  \item{\option{future.cmdargs}:}{(character vector) Overrides \code{\link[base]{commandArgs}()} when the \pkg{future} package is _loaded_.}
@@ -71,7 +93,7 @@
 #' \describe{
 #'  \item{\option{future.fork.multithreading.enable} (_beta feature - may change_):}{(logical) Enable or disable _multi-threading_ while using _forked_ parallel processing.  If `FALSE`, different multi-thread library settings are overridden such that they run in single-thread mode. Specifically, multi-threading will be disabled for OpenMP (which requires the \pkg{RhpcBLASctl} package) and for **RcppParallel**. If `TRUE`, or not set (the default), multi-threading is allowed.  Parallelization via multi-threaded processing (done in native code by some packages and external libraries) while at the same time using forked (aka "multicore") parallel processing is known to unstable.  Note that this is not only true when using `plan(multicore)` but also when using, for instance, \code{\link[=mclapply]{mclapply}()} of the \pkg{parallel} package. (Default: not set)}
 #'
-#'  \item{\option{future.output.windows.reencode} (_beta feature - may change_):}{(logical) Enable or disable re-encoding of UTF-8 symbols that were incorrectly encoded while captured.  On MS Windows, R cannot capture UTF-8 symbols as-is when they are captured from the standard output.  For examples, a UTF-8 check mark symbol (`"\u2713"`) would be relayed as `"<U+2713>"` (a string with eight ASCII characters).  This option will cause `value()` to attempt to recover the intended UTF-8 symbols from `<U+nnnn>` string components, if, and only if, the string was captured by a future resolved on MS Windows. (Default: `TRUE`)}
+#'  \item{\option{future.output.windows.reencode}:}{(logical) Enable or disable re-encoding of UTF-8 symbols that were incorrectly encoded while captured.  In R (< 4.2.0) and on older versions of MS Windows, R cannot capture UTF-8 symbols as-is when they are captured from the standard output.  For examples, a UTF-8 check mark symbol (`"\u2713"`) would be relayed as `"<U+2713>"` (a string with eight ASCII characters).  Setting this option to `TRUE` will cause `value()` to attempt to recover the intended UTF-8 symbols from `<U+nnnn>` string components, if, and only if, the string was captured by a future resolved on MS Windows. (Default: `TRUE`)}
 #' }
 #'
 #' See also [parallelly::parallelly.options].
@@ -104,10 +126,11 @@
 #' @section Environment variables that set R options:
 #' All of the above \R \option{future.*} options can be set by corresponding
 #' environment variable \env{R_FUTURE_*} _when the \pkg{future} package is
-#' loaded_.
-#' For example, if `R_FUTURE_RNG_ONMISUSE = "ignore"`, then option
+#' loaded_. This means that those environment variables must be set before
+#' the \pkg{future} package is loaded in order to have an effect.
+#' For example, if `R_FUTURE_RNG_ONMISUSE="ignore"`, then option
 #' \option{future.rng.onMisuse} is set to `"ignore"` (character string).
-#' Similarly, if `R_FUTURE_GLOBALS_MAXSIZE = "50000000"`, then option
+#' Similarly, if `R_FUTURE_GLOBALS_MAXSIZE="50000000"`, then option
 #' \option{future.globals.maxSize} is set to `50000000` (numeric).
 #'
 #' @examples
@@ -146,7 +169,13 @@
 #' R_FUTURE_GLOBALS_ONREFERENCE
 #' future.plan
 #' R_FUTURE_PLAN
+#' future.onFutureCondition.keepFuture
+#' R_FUTURE_ONFUTURECONDITION_KEEPFUTURE
 #' future.resolve.recursive
+#' R_FUTURE_RESOLVE_RECURSIVE
+#' future.globalenv.onMisuse
+#' R_FUTURE_GLOBALENV_ONMISUSE
+#' future.rng.onMisuse
 #' R_FUTURE_RNG_ONMISUSE
 #' future.wait.alpha
 #' R_FUTURE_WAIT_ALPHA
@@ -157,11 +186,22 @@
 #' R_FUTURE_RESOLVED_TIMEOUT
 #' future.output.windows.reencode
 #' R_FUTURE_OUTPUT_WINDOWS_REENCODE
+#' future.journal
+#' R_FUTURE_JOURNAL
+#' R_FUTURE_GLOBALS_OBJECTSIZE_METHOD
+#' future.globals.objectSize.method
 #'
 #' @name future.options
 NULL
 
 
+setOption <- function(name, value) {
+  oldValue <- getOption(name)
+  args <- list(value)
+  names(args) <- name
+  do.call(options, args = args)
+  invisible(oldValue)
+}
 
 
 # Set an R option from an environment variable
@@ -178,6 +218,7 @@ update_package_option <- function(name, mode = "character", default = NULL, spli
   ## Nothing to do?
   if (is.na(value)) {  
     if (debug) mdebugf("Environment variable %s not set", sQuote(env))
+    if (!is.null(default)) setOption(name, default)
     return(getOption(name, default = default))
   }
   
@@ -187,7 +228,10 @@ update_package_option <- function(name, mode = "character", default = NULL, spli
   if (trim) value <- trim(value)
 
   ## Nothing to do?
-  if (!nzchar(value)) return(getOption(name, default = default))
+  if (!nzchar(value)) {
+    if (!is.null(default)) setOption(name, default)
+    return(getOption(name, default = default))
+  }
 
   ## Split?
   if (!is.null(split)) {
@@ -209,7 +253,7 @@ update_package_option <- function(name, mode = "character", default = NULL, spli
 
   if (length(disallow) > 0) {
     if ("NA" %in% disallow) {
-      if (any(is.na(value))) {
+      if (anyNA(value)) {
         stopf("Coercing environment variable %s=%s to %s would result in missing values for option %s: %s", sQuote(env), sQuote(env_value), sQuote(mode), sQuote(name), commaq(value))
       }
     }
@@ -233,7 +277,7 @@ update_package_option <- function(name, mode = "character", default = NULL, spli
             length(value), storage.mode(value))
   }
 
-  do.call(options, args = structure(list(value), names = name))
+  setOption(name, value)
   
   getOption(name, default = default)
 }
@@ -247,6 +291,8 @@ update_package_options <- function(debug = FALSE) {
 
   update_package_option("future.deprecated.ignore", split = ",", debug = debug)
 
+  update_package_option("future.deprecated.defunct", mode = "character", split = ",", debug = debug)
+
   update_package_option("future.fork.multithreading.enable", mode = "logical", debug = debug)
 
   update_package_option("future.globals.maxSize", mode = "numeric", debug = debug)
@@ -273,26 +319,47 @@ update_package_options <- function(debug = FALSE) {
 
   update_package_option("future.resolve.recursive", mode = "integer", debug = debug)
 
+  ## Introduced in future 1.33.0:
+  update_package_option("future.alive.timeout", mode = "numeric", debug = debug)
+
   ## Introduced in future 1.22.0:
   for (name in c("future.resolved.timeout", "future.cluster.resolved.timeout", "future.multicore.resolved.timeout")) {
     update_package_option(name, mode = "numeric", debug = debug)
   }
 
+  ## Introduced in future 1.32.0:
+  update_package_option("future.onFutureCondition.keepFuture", mode = "logical", debug = debug)
+
   update_package_option("future.rng.onMisuse", debug = debug)
-  update_package_option("future.rng.onMisuse.keepFuture", mode = "logical", debug = debug)
   
+  ## Prototyping in future 1.32.0:
+  update_package_option("future.globalenv.onMisuse", debug = debug)
+
   update_package_option("future.wait.timeout", mode = "numeric", debug = debug)
   update_package_option("future.wait.interval", mode = "numeric", debug = debug)
   update_package_option("future.wait.alpha", mode = "numeric", debug = debug)
 
   ## Prototyping in future 1.22.0:
   ## https://github.com/HenrikBengtsson/future/issues/515
-  update_package_option("future.assign_globals.exclude", default = c("namespace"), split = ",", debug = debug)
+  update_package_option("future.assign_globals.exclude", split = ",", debug = debug)
 
   ## Prototyping in future 1.23.0:
   update_package_option("future.output.windows.reencode", mode = "logical", debug = debug)
 
+  ## Prototyping in future 1.26.0:
+  update_package_option("future.globals.globalsOf.locals", mode = "logical", debug = debug)
+
+  ## future 1.32.0:
+  update_package_option("future.state.onInvalid", mode = "character", debug = debug)
+
+  ## future 1.32.0:
+  update_package_option("future.journal", mode = "logical", debug = debug)
+
   ## SETTINGS USED FOR DEPRECATING FEATURES
   ## future 1.22.0:
   update_package_option("future.globals.keepWhere", mode = "logical", debug = debug)
+
+  ## future 1.34.0:
+  update_package_option("future.globals.objectSize.method", mode = "character", debug = debug)
+  update_package_option("future.plan.cleanup.legacy", mode = "logical", debug = debug)
 }
