@@ -17,12 +17,6 @@
 
   ## Set future options based on environment variables
   update_package_options(debug = debug)
-
-  ## Does multiprocess resolve to multisession? If so, then
-  ## plan(multiprocess) should initiate the workers.
-  if (is.na(attr(multiprocess, "init", exact = TRUE))) {
-    attr(multiprocess, "init") <<- !supportsMulticore()
-  }
   
   ## Initiate the R session UUID, which will also set/update
   ## .GlobalEnv$.Random.seed.
