@@ -17,12 +17,6 @@ print(v)
 ex <- FutureError(message = "Woops", future = f)
 print(ex)
 
-## Deprecated
-res <- tryCatch({
-  FutureError(message = "Woops", future = f, output = "Boom")
-}, warning = identity)
-stopifnot(inherits(res, "warning"))
-
 message("*** FutureError class ... DONE")
 
 source("incl/end.R")
