@@ -1,5 +1,4 @@
 source("incl/start.R")
-library("listenv")
 options(future.debug = FALSE)
 message("*** cluster() ...")
 
@@ -65,10 +64,6 @@ for (type in types) {
     print(y)
     stopifnot(y == 42L)
 
-
-    ## Set up a cluster with <cores> nodes (implicitly)
-    plan(cluster, workers = cores)
-  
     ## No global variables
     f <- try(cluster({
       42L
@@ -81,7 +76,6 @@ for (type in types) {
     print(y)
     stopifnot(y == 42L)
   
-  
     ## A global variable
     a <- 0
     f <- try(future({
@@ -100,17 +94,18 @@ for (type in types) {
     v <- value(f)
     print(v)
     stopifnot(v == 0)
-  
-  
-    message("*** cluster() with globals and blocking")
-    x <- listenv()
-    for (ii in 1:3) {
-      message(sprintf(" - Creating cluster future #%d ...", ii))
-      x[[ii]] <- future({ ii })
+
+    if (!"covr" %in% loadedNamespaces()) {
+      message("*** cluster() with globals and blocking")
+      fs <- list()
+      for (ii in 1:3) {
+        message(sprintf(" - Creating cluster future #%d ...", ii))
+        fs[[ii]] <- future({ ii }, label = sprintf("future-%d", ii))
+      }
+      message(sprintf(" - Resolving %d cluster futures", length(fs)))
+      v <- sapply(fs, FUN = value)
+      stopifnot(all(v == 1:3))
     }
-    message(sprintf(" - Resolving %d cluster futures", length(x)))
-    v <- sapply(x, FUN = value)
-    stopifnot(all(v == 1:3))
   
   
     message("*** cluster() and errors")
@@ -146,39 +141,6 @@ for (type in types) {
     res <- tryCatch(value(f), error = identity)
     stopifnot(inherits(res, "error"), inherits(res, "MyError"))    
   
-    message("*** cluster() - too large globals ...")
-    ooptsT <- options(future.globals.maxSize = object.size(1:1014))
-  
-    limit <- getOption("future.globals.maxSize")
-    cat(sprintf("Max total size of globals: %g bytes\n", limit))
-  
-    ## A large object
-    a <- 1:1014
-    yTruth <- sum(a)
-    size <- object.size(a)
-    cat(sprintf("a: %g bytes\n", size))
-    f <- future({ sum(a) })
-    print(f)
-    rm(list = "a")
-    v <- value(f)
-    print(v)
-    stopifnot(v == yTruth)
-  
-  
-    ## A too large object
-    a <- 1:1015
-    yTruth <- sum(a)
-    size <- object.size(a)
-    cat(sprintf("a: %g bytes\n", size))
-    res <- tryCatch(f <- future({ sum(a) }), error = identity)
-    rm(list = "a")
-    stopifnot(inherits(res, "error"))
-  
-    ## Undo options changed in this test
-    options(ooptsT)
-  
-    message("*** cluster() - too large globals ... DONE")
-  
     message("*** cluster() - installed libraries ...")
     f <- try(cluster({
       list(
@@ -218,6 +180,9 @@ for (type in types) {
     message("Main PID: ", pid2)
     stopifnot(pid2 == pid)
 
+    ## Cleanup
+    parallel::stopCluster(cl)
+  
     message(sprintf("Testing with %d cores on type = %s ... DONE",
                     cores, sQuote(type)))
   } ## for (cores ...)
@@ -242,6 +207,11 @@ for (type in types) {
   plan(sequential)
   clR <- ClusterRegistry("get")
   stopifnot(is.null(clR))
+
+  ## Cleanup
+  print(cl)
+  str(cl)
+  parallel::stopCluster(cl)
   
   message("*** cluster() - assert registry behavior ... DONE")
 
@@ -252,17 +222,16 @@ for (type in types) {
   stopifnot(pid2 == pid)
 
   ## Cleanup
-  print(cl)
-  str(cl)
-  parallel::stopCluster(cl)
   plan(sequential)
 
   cl1 <- parallel::makeCluster(1L, type = type, timeout = 60)
   plan(cluster, workers = cl1)
   f1 <- future(1)
 
-  cl1 <- parallel::makeCluster(1L, type = type, timeout = 60)
-  plan(cluster, workers = cl1)
+  ## Cleanup
+  print(cl1)
+  str(cl1)
+  parallel::stopCluster(cl1)
 
   message(sprintf("Test set #1 with cluster type %s ... DONE", sQuote(type)))
 } ## for (type ...)
@@ -290,6 +259,11 @@ for (type in types) {
   message(a)
   
   setDefaultCluster(NULL)
+
+  ## Cleanup
+  print(cl)
+  str(cl)
+  parallel::stopCluster(cl)
   
   message("*** cluster() - setDefaultCluster() ... DONE")
 
@@ -300,9 +274,6 @@ for (type in types) {
   stopifnot(pid2 == pid)
 
   ## Cleanup
-  print(cl)
-  str(cl)
-  parallel::stopCluster(cl)
   plan(sequential)
 
   message(sprintf("Test set #2 with cluster type %s ... DONE", sQuote(type)))
