@@ -1,3 +1,7 @@
+## Load namespace already here; it'll set some options based on
+## environment variables
+loadNamespace("future")
+
 ## Record original state
 ovars <- ls()
 oenvs <- oenvs0 <- Sys.getenv()
@@ -22,22 +26,22 @@ oopts <- options(
 ## Comment: The below should be set automatically whenever the future package
 ## is loaded and 'R CMD check' runs.  The below is added in case R is changed
 ## in the future and we fail to detect 'R CMD check'.
-Sys.setenv(R_FUTURE_MAKENODEPSOCK_CONNECTTIMEOUT = 2 * 60)
-Sys.setenv(R_FUTURE_MAKENODEPSOCK_TIMEOUT = 2 * 60)
+Sys.setenv(R_PARALLELLY_MAKENODEPSOCK_CONNECTTIMEOUT = 2 * 60)
+Sys.setenv(R_PARALLELLY_MAKENODEPSOCK_TIMEOUT = 2 * 60)
+Sys.setenv(R_PARALLELLY_MAKENODEPSOCK_SESSIONINFO_PKGS = TRUE)
 Sys.setenv(R_FUTURE_WAIT_INTERVAL = 0.01) ## 0.01s (instead of default 0.2s)
-Sys.setenv(R_FUTURE_MAKENODEPSOCK_SESSIONINFO_PKGS = TRUE)
 
 ## Label PSOCK cluster workers (to help troubleshooting)
 test_script <- grep("[.]R$", commandArgs(), value = TRUE)[1]
 if (is.na(test_script)) test_script <- "UNKNOWN"
 worker_label <- sprintf("future/tests/%s:%s:%s:%s", test_script, Sys.info()[["nodename"]], Sys.info()[["user"]], Sys.getpid())
-Sys.setenv(R_FUTURE_MAKENODEPSOCK_RSCRIPT_LABEL = worker_label)
+Sys.setenv(R_PARALLELLY_MAKENODEPSOCK_RSCRIPT_LABEL = worker_label)
 
 ## Reset the following during testing in case
 ## they are set on the test system
 oenvs2 <- Sys.unsetenv(c(
-  "R_FUTURE_AVAILABLECORES_SYSTEM",
-  "R_FUTURE_AVAILABLECORES_FALLBACK",
+  "R_PARALLELLY_AVAILABLECORES_SYSTEM",
+  "R_PARALLELLY_AVAILABLECORES_FALLBACK",
   ## SGE
   "NSLOTS", "PE_HOSTFILE",
   ## Slurm
@@ -48,7 +52,7 @@ oenvs2 <- Sys.unsetenv(c(
 
 oplan <- future::plan()
 
-## Use eager futures by default
+## Use sequential futures by default
 future::plan("sequential")
 
 fullTest <- (Sys.getenv("_R_CHECK_FULL_") != "")
@@ -66,23 +70,25 @@ get_future <- future:::get_future
 geval <- future:::geval
 grmall <- future:::grmall
 hpaste <- future:::hpaste
-inRCmdCheck <- future:::inRCmdCheck
 importParallel <- future:::importParallel
 mdebug <- future:::mdebug
 mdebugf <- future:::mdebugf
-myExternalIP <- future:::myExternalIP
-myInternalIP <- future:::myInternalIP
 parseCmdArgs <- future:::parseCmdArgs
 requestCore <- future:::requestCore
 requestNode <- future:::requestNode
 requirePackages <- future:::requirePackages
 tweakExpression <- future:::tweakExpression
 whichIndex <- future:::whichIndex
-pid_exists <- future:::pid_exists
 isFALSE <- future:::isFALSE
 isNA <- future:::isNA
 supports_omp_threads <- future:::supports_omp_threads
 
+get_random_seed <- future:::get_random_seed
+set_random_seed <- future:::set_random_seed
+next_random_seed <- future:::next_random_seed
+as_lecyer_cmrg_seed <- future:::as_lecyer_cmrg_seed
+is_lecyer_cmrg_seed <- future:::is_lecyer_cmrg_seed
+
 ## Local functions for test scripts
 printf <- function(...) cat(sprintf(...))
 mstr <- function(...) message(paste(capture.output(str(...)), collapse = "\n"))
@@ -100,14 +106,10 @@ supportedStrategies <- function(cores = NA_integer_, excl = "cluster", ...) {
     if (cores == 1L) {
       strategies <- setdiff(strategies, c("multicore", "multisession"))
     } else if (cores > 1L) {
-      strategies <- setdiff(strategies,
-                            c("sequential", "uniprocess", "eager", "lazy"))
+      strategies <- setdiff(strategies, "sequential")
     }
   }
   
-  ## Don't test deprecated 'multiprocess'
-  strategies <- setdiff(strategies, "multiprocess")
-  
   strategies
 }
 
