@@ -51,7 +51,7 @@ for (strategy1 in strategies) {
           length(nested_b) == 0L,
           length(plan_b) == 1L,
           inherits(plan_b[[1]], "future"),
-          inherits(future::plan("next"), getOption("future.plan", "sequential"))
+          inherits(future::plan("next"), "sequential")
         )
 
         list(a = a, nested_a = nested_a, plan_a = plan_a,
@@ -78,7 +78,7 @@ for (strategy1 in strategies) {
       is.list(x$plan_b),
       length(x$plan_b) == 1L,
       inherits(x$plan_b[[1]], "future"),
-      inherits(x$plan_b[[1]], getOption("future.plan", "sequential"))
+      inherits(x$plan_b[[1]], "sequential")
     )
 
     ## Attribute 'init' is modified at run time
